Make your #AdventOfCode problem twice as fast with this one weird trick ... I was absolutely sure the compiler (clang-18) would do this for me, but alas, it didn't.... Went from ~40ms to ~20ms. Hat tip to @49pctber.bsky.social I peeked at their code and was like "nah, THAT can't be it..."
Post
No replies yet.